# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from originstamp_client.models.usage_response import UsageResponse  # noqa: F401,E501


class DefaultUsageResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'UsageResponse',
        'error_code': 'int',
        'error_message': 'str'
    }

    attribute_map = {
        'data': 'data',
        'error_code': 'error_code',
        'error_message': 'error_message'
    }

    def __init__(self, data=None, error_code=None, error_message=None):  # noqa: E501
        """DefaultUsageResponse - a model defined in Swagger"""  # noqa: E501

        self._data = None
        self._error_code = None
        self._error_message = None
        self.discriminator = None

        if data is not None:
            self.data = data
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message

    @property
    def data(self):
        """Gets the data of this DefaultUsageResponse.  # noqa: E501

        Generic response object which contains the response data, e.g. timestamp information.  # noqa: E501

        :return: The data of this DefaultUsageResponse.  # noqa: E501
        :rtype: UsageResponse
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this DefaultUsageResponse.

        Generic response object which contains the response data, e.g. timestamp information.  # noqa: E501

        :param data: The data of this DefaultUsageResponse.  # noqa: E501
        :type: UsageResponse
        """

        self._data = data

    @property
    def error_code(self):
        """Gets the error_code of this DefaultUsageResponse.  # noqa: E501

        Contains the error of the request. If the error code is 0, everything is fine.  # noqa: E501

        :return: The error_code of this DefaultUsageResponse.  # noqa: E501
        :rtype: int
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this DefaultUsageResponse.

        Contains the error of the request. If the error code is 0, everything is fine.  # noqa: E501

        :param error_code: The error_code of this DefaultUsageResponse.  # noqa: E501
        :type: int
        """

        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this DefaultUsageResponse.  # noqa: E501

        Contains the error message, that possibly occurred. If it is empty, everything is fine.  # noqa: E501

        :return: The error_message of this DefaultUsageResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this DefaultUsageResponse.

        Contains the error message, that possibly occurred. If it is empty, everything is fine.  # noqa: E501

        :param error_message: The error_message of this DefaultUsageResponse.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DefaultUsageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class UsageResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'consumed_credits': 'float',
        'credits_per_month': 'float',
        'remaining_credits': 'float'
    }

    attribute_map = {
        'consumed_credits': 'consumed_credits',
        'credits_per_month': 'credits_per_month',
        'remaining_credits': 'remaining_credits'
    }

    def __init__(self, consumed_credits=None, credits_per_month=None, remaining_credits=None):  # noqa: E501
        """UsageResponse - a model defined in Swagger"""  # noqa: E501

        self._consumed_credits = None
        self._credits_per_month = None
        self._remaining_credits = None
        self.discriminator = None

        if consumed_credits is not None:
            self.consumed_credits = consumed_credits
        if credits_per_month is not None:
            self.credits_per_month = credits_per_month
        if remaining_credits is not None:
            self.remaining_credits = remaining_credits

    @property
    def consumed_credits(self):
        """Gets the consumed_credits of this UsageResponse.  # noqa: E501

        Represents the number of used credits for the current month.  # noqa: E501

        :return: The consumed_credits of this UsageResponse.  # noqa: E501
        :rtype: float
        """
        return self._consumed_credits

    @consumed_credits.setter
    def consumed_credits(self, consumed_credits):
        """Sets the consumed_credits of this UsageResponse.

        Represents the number of used credits for the current month.  # noqa: E501

        :param consumed_credits: The consumed_credits of this UsageResponse.  # noqa: E501
        :type: float
        """

        self._consumed_credits = consumed_credits

    @property
    def credits_per_month(self):
        """Gets the credits_per_month of this UsageResponse.  # noqa: E501

        Represents the total number of credits per month.  # noqa: E501

        :return: The credits_per_month of this UsageResponse.  # noqa: E501
        :rtype: float
        """
        return self._credits_per_month

    @credits_per_month.setter
    def credits_per_month(self, credits_per_month):
        """Sets the credits_per_month of this UsageResponse.

        Represents the total number of credits per month.  # noqa: E501

        :param credits_per_month: The credits_per_month of this UsageResponse.  # noqa: E501
        :type: float
        """

        self._credits_per_month = credits_per_month

    @property
    def remaining_credits(self):
        """Gets the remaining_credits of this UsageResponse.  # noqa: E501

        Represents the remaining number of credits for the current month.  # noqa: E501

        :return: The remaining_credits of this UsageResponse.  # noqa: E501
        :rtype: float
        """
        return self._remaining_credits

    @remaining_credits.setter
    def remaining_credits(self, remaining_credits):
        """Sets the remaining_credits of this UsageResponse.

        Represents the remaining number of credits for the current month.  # noqa: E501

        :param remaining_credits: The remaining_credits of this UsageResponse.  # noqa: E501
        :type: float
        """

        self._remaining_credits = remaining_credits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UsageResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class WebhookRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hash': 'str',
        'webhook_url': 'str'
    }

    attribute_map = {
        'hash': 'hash',
        'webhook_url': 'webhook_url'
    }

    def __init__(self, hash=None, webhook_url=None):  # noqa: E501
        """WebhookRequest - a model defined in Swagger"""  # noqa: E501

        self._hash = None
        self._webhook_url = None
        self.discriminator = None

        self.hash = hash
        self.webhook_url = webhook_url

    @property
    def hash(self):
        """Gets the hash of this WebhookRequest.  # noqa: E501

        SHA-256 Hash in Hex representation  # noqa: E501

        :return: The hash of this WebhookRequest.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this WebhookRequest.

        SHA-256 Hash in Hex representation  # noqa: E501

        :param hash: The hash of this WebhookRequest.  # noqa: E501
        :type: str
        """
        if hash is None:
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501

        self._hash = hash

    @property
    def webhook_url(self):
        """Gets the webhook_url of this WebhookRequest.  # noqa: E501

        target url that should receive the webhook  # noqa: E501

        :return: The webhook_url of this WebhookRequest.  # noqa: E501
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """Sets the webhook_url of this WebhookRequest.

        target url that should receive the webhook  # noqa: E501

        :param webhook_url: The webhook_url of this WebhookRequest.  # noqa: E501
        :type: str
        """
        if webhook_url is None:
            raise ValueError("Invalid value for `webhook_url`, must not be `None`")  # noqa: E501

        self._webhook_url = webhook_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WebhookRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TimestampData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency_id': 'int',
        'private_key': 'str',
        'submit_status': 'int',
        'timestamp': 'int',
        'transaction': 'str'
    }

    attribute_map = {
        'currency_id': 'currency_id',
        'private_key': 'private_key',
        'submit_status': 'submit_status',
        'timestamp': 'timestamp',
        'transaction': 'transaction'
    }

    def __init__(self, currency_id=None, private_key=None, submit_status=None, timestamp=None, transaction=None):  # noqa: E501
        """TimestampData - a model defined in Swagger"""  # noqa: E501

        self._currency_id = None
        self._private_key = None
        self._submit_status = None
        self._timestamp = None
        self._transaction = None
        self.discriminator = None

        if currency_id is not None:
            self.currency_id = currency_id
        if private_key is not None:
            self.private_key = private_key
        if submit_status is not None:
            self.submit_status = submit_status
        if timestamp is not None:
            self.timestamp = timestamp
        if transaction is not None:
            self.transaction = transaction

    @property
    def currency_id(self):
        """Gets the currency_id of this TimestampData.  # noqa: E501

        0: Bitcoin  # noqa: E501

        :return: The currency_id of this TimestampData.  # noqa: E501
        :rtype: int
        """
        return self._currency_id

    @currency_id.setter
    def currency_id(self, currency_id):
        """Sets the currency_id of this TimestampData.

        0: Bitcoin  # noqa: E501

        :param currency_id: The currency_id of this TimestampData.  # noqa: E501
        :type: int
        """

        self._currency_id = currency_id

    @property
    def private_key(self):
        """Gets the private_key of this TimestampData.  # noqa: E501

        The private key represents the top hash in the Merkle Tree (see https://en.wikipedia.org/wiki/Merkle_tree ) or the hash of all hashes in the transaction.  # noqa: E501

        :return: The private_key of this TimestampData.  # noqa: E501
        :rtype: str
        """
        return self._private_key

    @private_key.setter
    def private_key(self, private_key):
        """Sets the private_key of this TimestampData.

        The private key represents the top hash in the Merkle Tree (see https://en.wikipedia.org/wiki/Merkle_tree ) or the hash of all hashes in the transaction.  # noqa: E501

        :param private_key: The private_key of this TimestampData.  # noqa: E501
        :type: str
        """

        self._private_key = private_key

    @property
    def submit_status(self):
        """Gets the submit_status of this TimestampData.  # noqa: E501

        The submit status of the hash:   0: the hash was not broadcasted yet  1: the hash was included into a transaction and broadcasted to the network, but not included into a block  2: the transaction was included into the latest block  3: the timestamp for your hash was successfully created.  # noqa: E501

        :return: The submit_status of this TimestampData.  # noqa: E501
        :rtype: int
        """
        return self._submit_status

    @submit_status.setter
    def submit_status(self, submit_status):
        """Sets the submit_status of this TimestampData.

        The submit status of the hash:   0: the hash was not broadcasted yet  1: the hash was included into a transaction and broadcasted to the network, but not included into a block  2: the transaction was included into the latest block  3: the timestamp for your hash was successfully created.  # noqa: E501

        :param submit_status: The submit_status of this TimestampData.  # noqa: E501
        :type: int
        """

        self._submit_status = submit_status

    @property
    def timestamp(self):
        """Gets the timestamp of this TimestampData.  # noqa: E501

        The date is returned in the following format: [ms] since 1.1.1970 (unix epoch), timezone: UTC. This is a true timestamp.  # noqa: E501

        :return: The timestamp of this TimestampData.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this TimestampData.

        The date is returned in the following format: [ms] since 1.1.1970 (unix epoch), timezone: UTC. This is a true timestamp.  # noqa: E501

        :param timestamp: The timestamp of this TimestampData.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def transaction(self):
        """Gets the transaction of this TimestampData.  # noqa: E501

        If available: the transaction hash of the timestamp.  # noqa: E501

        :return: The transaction of this TimestampData.  # noqa: E501
        :rtype: str
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this TimestampData.

        If available: the transaction hash of the timestamp.  # noqa: E501

        :param transaction: The transaction of this TimestampData.  # noqa: E501
        :type: str
        """

        self._transaction = transaction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimestampData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from originstamp_client.models.notification import Notification  # noqa: F401,E501


class TimestampRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'hash': 'str',
        'notifications': 'list[Notification]',
        'url': 'str'
    }

    attribute_map = {
        'comment': 'comment',
        'hash': 'hash',
        'notifications': 'notifications',
        'url': 'url'
    }

    def __init__(self, comment=None, hash=None, notifications=None, url=None):  # noqa: E501
        """TimestampRequest - a model defined in Swagger"""  # noqa: E501

        self._comment = None
        self._hash = None
        self._notifications = None
        self._url = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        self.hash = hash
        if notifications is not None:
            self.notifications = notifications
        if url is not None:
            self.url = url

    @property
    def comment(self):
        """Gets the comment of this TimestampRequest.  # noqa: E501

        You can add a short comment (max. 256 characters) which can be used for indexing and searching (public).  # noqa: E501

        :return: The comment of this TimestampRequest.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this TimestampRequest.

        You can add a short comment (max. 256 characters) which can be used for indexing and searching (public).  # noqa: E501

        :param comment: The comment of this TimestampRequest.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def hash(self):
        """Gets the hash of this TimestampRequest.  # noqa: E501

        Hash in HEX representation. We suggest to use SHA-256. This hash will be aggregated and included into the blockchain.  # noqa: E501

        :return: The hash of this TimestampRequest.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this TimestampRequest.

        Hash in HEX representation. We suggest to use SHA-256. This hash will be aggregated and included into the blockchain.  # noqa: E501

        :param hash: The hash of this TimestampRequest.  # noqa: E501
        :type: str
        """
        if hash is None:
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501

        self._hash = hash

    @property
    def notifications(self):
        """Gets the notifications of this TimestampRequest.  # noqa: E501

        Add a notification/notification list to your submission. Our system will notify the specified target with the timestamp information.  # noqa: E501

        :return: The notifications of this TimestampRequest.  # noqa: E501
        :rtype: list[Notification]
        """
        return self._notifications

    @notifications.setter
    def notifications(self, notifications):
        """Sets the notifications of this TimestampRequest.

        Add a notification/notification list to your submission. Our system will notify the specified target with the timestamp information.  # noqa: E501

        :param notifications: The notifications of this TimestampRequest.  # noqa: E501
        :type: list[Notification]
        """

        self._notifications = notifications

    @property
    def url(self):
        """Gets the url of this TimestampRequest.  # noqa: E501

        Preprint URL. Insert the generated UUID here. You can generate an UUID-4 and include it into your document: https://originstamp.org/u/uuid4. When submitting the your file, the url is part of the hash, which finally means it the link to the timestamp is part of the timestamp.  # noqa: E501

        :return: The url of this TimestampRequest.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this TimestampRequest.

        Preprint URL. Insert the generated UUID here. You can generate an UUID-4 and include it into your document: https://originstamp.org/u/uuid4. When submitting the your file, the url is part of the hash, which finally means it the link to the timestamp is part of the timestamp.  # noqa: E501

        :param url: The url of this TimestampRequest.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimestampRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Notification(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'currency': 'int',
        'notification_type': 'int',
        'target': 'str'
    }

    attribute_map = {
        'currency': 'currency',
        'notification_type': 'notification_type',
        'target': 'target'
    }

    def __init__(self, currency=None, notification_type=None, target=None):  # noqa: E501
        """Notification - a model defined in Swagger"""  # noqa: E501

        self._currency = None
        self._notification_type = None
        self._target = None
        self.discriminator = None

        self.currency = currency
        self.notification_type = notification_type
        self.target = target

    @property
    def currency(self):
        """Gets the currency of this Notification.  # noqa: E501

        0: Bitcoin  # noqa: E501

        :return: The currency of this Notification.  # noqa: E501
        :rtype: int
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Notification.

        0: Bitcoin  # noqa: E501

        :param currency: The currency of this Notification.  # noqa: E501
        :type: int
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def notification_type(self):
        """Gets the notification_type of this Notification.  # noqa: E501

        0: notify via email  1: notify a webhook  # noqa: E501

        :return: The notification_type of this Notification.  # noqa: E501
        :rtype: int
        """
        return self._notification_type

    @notification_type.setter
    def notification_type(self, notification_type):
        """Sets the notification_type of this Notification.

        0: notify via email  1: notify a webhook  # noqa: E501

        :param notification_type: The notification_type of this Notification.  # noqa: E501
        :type: int
        """
        if notification_type is None:
            raise ValueError("Invalid value for `notification_type`, must not be `None`")  # noqa: E501

        self._notification_type = notification_type

    @property
    def target(self):
        """Gets the target of this Notification.  # noqa: E501

        Depending on the notification type, specify the target for the notification (e.g. email address or webhook url). The webhook url will reveive a POST request after timestamp was successfully created.  # noqa: E501

        :return: The target of this Notification.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this Notification.

        Depending on the notification type, specify the target for the notification (e.g. email address or webhook url). The webhook url will reveive a POST request after timestamp was successfully created.  # noqa: E501

        :param target: The target of this Notification.  # noqa: E501
        :type: str
        """
        if target is None:
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Notification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResponseEntity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'body': 'object',
        'status_code': 'str',
        'status_code_value': 'int'
    }

    attribute_map = {
        'body': 'body',
        'status_code': 'statusCode',
        'status_code_value': 'statusCodeValue'
    }

    def __init__(self, body=None, status_code=None, status_code_value=None):  # noqa: E501
        """ResponseEntity - a model defined in Swagger"""  # noqa: E501

        self._body = None
        self._status_code = None
        self._status_code_value = None
        self.discriminator = None

        if body is not None:
            self.body = body
        if status_code is not None:
            self.status_code = status_code
        if status_code_value is not None:
            self.status_code_value = status_code_value

    @property
    def body(self):
        """Gets the body of this ResponseEntity.  # noqa: E501


        :return: The body of this ResponseEntity.  # noqa: E501
        :rtype: object
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ResponseEntity.


        :param body: The body of this ResponseEntity.  # noqa: E501
        :type: object
        """

        self._body = body

    @property
    def status_code(self):
        """Gets the status_code of this ResponseEntity.  # noqa: E501


        :return: The status_code of this ResponseEntity.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this ResponseEntity.


        :param status_code: The status_code of this ResponseEntity.  # noqa: E501
        :type: str
        """
        allowed_values = ["100", "101", "102", "103", "200", "201", "202", "203", "204", "205", "206", "207", "208", "226", "300", "301", "302", "303", "304", "305", "307", "308", "400", "401", "402", "403", "404", "405", "406", "407", "408", "409", "410", "411", "412", "413", "414", "415", "416", "417", "418", "419", "420", "421", "422", "423", "424", "426", "428", "429", "431", "451", "500", "501", "502", "503", "504", "505", "506", "507", "508", "509", "510", "511"]  # noqa: E501
        if status_code not in allowed_values:
            raise ValueError(
                "Invalid value for `status_code` ({0}), must be one of {1}"  # noqa: E501
                .format(status_code, allowed_values)
            )

        self._status_code = status_code

    @property
    def status_code_value(self):
        """Gets the status_code_value of this ResponseEntity.  # noqa: E501


        :return: The status_code_value of this ResponseEntity.  # noqa: E501
        :rtype: int
        """
        return self._status_code_value

    @status_code_value.setter
    def status_code_value(self, status_code_value):
        """Sets the status_code_value of this ResponseEntity.


        :param status_code_value: The status_code_value of this ResponseEntity.  # noqa: E501
        :type: int
        """

        self._status_code_value = status_code_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseEntity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from originstamp_client.models.default_scheduler_response import DefaultSchedulerResponse
from originstamp_client.models.default_timestamp_response import DefaultTimestampResponse
from originstamp_client.models.default_usage_response import DefaultUsageResponse
from originstamp_client.models.defaultstring import Defaultstring
from originstamp_client.models.notification import Notification
from originstamp_client.models.proof_request import ProofRequest
from originstamp_client.models.response_entity import ResponseEntity
from originstamp_client.models.scheduler_request import SchedulerRequest
from originstamp_client.models.scheduler_response import SchedulerResponse
from originstamp_client.models.timestamp_data import TimestampData
from originstamp_client.models.timestamp_request import TimestampRequest
from originstamp_client.models.timestamp_response import TimestampResponse
from originstamp_client.models.usage_response import UsageResponse
from originstamp_client.models.webhook_request import WebhookRequest



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from originstamp_client.models.timestamp_data import TimestampData  # noqa: F401,E501


class TimestampResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'created': 'bool',
        'date_created': 'int',
        'hash_string': 'str',
        'timestamps': 'list[TimestampData]'
    }

    attribute_map = {
        'comment': 'comment',
        'created': 'created',
        'date_created': 'date_created',
        'hash_string': 'hash_string',
        'timestamps': 'timestamps'
    }

    def __init__(self, comment=None, created=None, date_created=None, hash_string=None, timestamps=None):  # noqa: E501
        """TimestampResponse - a model defined in Swagger"""  # noqa: E501

        self._comment = None
        self._created = None
        self._date_created = None
        self._hash_string = None
        self._timestamps = None
        self.discriminator = None

        if comment is not None:
            self.comment = comment
        if created is not None:
            self.created = created
        if date_created is not None:
            self.date_created = date_created
        if hash_string is not None:
            self.hash_string = hash_string
        if timestamps is not None:
            self.timestamps = timestamps

    @property
    def comment(self):
        """Gets the comment of this TimestampResponse.  # noqa: E501

        The comment which was added in the submission of the hash.  # noqa: E501

        :return: The comment of this TimestampResponse.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this TimestampResponse.

        The comment which was added in the submission of the hash.  # noqa: E501

        :param comment: The comment of this TimestampResponse.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def created(self):
        """Gets the created of this TimestampResponse.  # noqa: E501

        Field is set to true if it is a novel hash. If the flag is false, the hash was already submitted before.  # noqa: E501

        :return: The created of this TimestampResponse.  # noqa: E501
        :rtype: bool
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this TimestampResponse.

        Field is set to true if it is a novel hash. If the flag is false, the hash was already submitted before.  # noqa: E501

        :param created: The created of this TimestampResponse.  # noqa: E501
        :type: bool
        """

        self._created = created

    @property
    def date_created(self):
        """Gets the date_created of this TimestampResponse.  # noqa: E501

        The time when your hash was submitted to OriginStamp. The date is returned in the following format: [ms] since 1.1.1970 (unix epoch), timezone: UTC. This is not considered as a true timestamp.  # noqa: E501

        :return: The date_created of this TimestampResponse.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this TimestampResponse.

        The time when your hash was submitted to OriginStamp. The date is returned in the following format: [ms] since 1.1.1970 (unix epoch), timezone: UTC. This is not considered as a true timestamp.  # noqa: E501

        :param date_created: The date_created of this TimestampResponse.  # noqa: E501
        :type: int
        """

        self._date_created = date_created

    @property
    def hash_string(self):
        """Gets the hash_string of this TimestampResponse.  # noqa: E501

        The submitted hash in hex representation.  # noqa: E501

        :return: The hash_string of this TimestampResponse.  # noqa: E501
        :rtype: str
        """
        return self._hash_string

    @hash_string.setter
    def hash_string(self, hash_string):
        """Sets the hash_string of this TimestampResponse.

        The submitted hash in hex representation.  # noqa: E501

        :param hash_string: The hash_string of this TimestampResponse.  # noqa: E501
        :type: str
        """

        self._hash_string = hash_string

    @property
    def timestamps(self):
        """Gets the timestamps of this TimestampResponse.  # noqa: E501

        Contains all the timestamp data of your hash until now.  # noqa: E501

        :return: The timestamps of this TimestampResponse.  # noqa: E501
        :rtype: list[TimestampData]
        """
        return self._timestamps

    @timestamps.setter
    def timestamps(self, timestamps):
        """Sets the timestamps of this TimestampResponse.

        Contains all the timestamp data of your hash until now.  # noqa: E501

        :param timestamps: The timestamps of this TimestampResponse.  # noqa: E501
        :type: list[TimestampData]
        """

        self._timestamps = timestamps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimestampResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from originstamp_client.api_client import ApiClient


class TimestampApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_timestamp(self, authorization, timestamp_request, **kwargs):  # noqa: E501
        """Submission  # noqa: E501

        You can submit your hash with this function. If your api key is valid, your hash is added to batch and is scheduled for timestamping. If the hash already exists, the created flag in the response is set to false and the notification(s) of the current request will be totally ignored. You are also able to submit additional information, such as comment or notification credentials. Once a hash is successfully created for a certain crypto-currency, we can notify your desired target with the timestamp information (POST Request). The webhook is triggered as soon as the tamper-proof timestamp with the selected crypto currency has been created. Additionally, it is possible to include a preprint URL in the hash submission. Before the generation of the timestamp hash you can create a random UUID Version 4 and include https://originstamp.com/u/UUID where UUID is your UUID e.g. in a document you want to timestamp. In the preprint URL field you include your UUID and then it is possible to verify the timestamp within the document (or whatever).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_timestamp(authorization, timestamp_request, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param TimestampRequest timestamp_request: DTO for the hash submission. Add all relevant information concerning your hash submission. (required)
        :return: DefaultTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.create_timestamp_with_http_info(authorization, timestamp_request, **kwargs)  # noqa: E501
        else:
            (data) = self.create_timestamp_with_http_info(authorization, timestamp_request, **kwargs)  # noqa: E501
            return data

    def create_timestamp_with_http_info(self, authorization, timestamp_request, **kwargs):  # noqa: E501
        """Submission  # noqa: E501

        You can submit your hash with this function. If your api key is valid, your hash is added to batch and is scheduled for timestamping. If the hash already exists, the created flag in the response is set to false and the notification(s) of the current request will be totally ignored. You are also able to submit additional information, such as comment or notification credentials. Once a hash is successfully created for a certain crypto-currency, we can notify your desired target with the timestamp information (POST Request). The webhook is triggered as soon as the tamper-proof timestamp with the selected crypto currency has been created. Additionally, it is possible to include a preprint URL in the hash submission. Before the generation of the timestamp hash you can create a random UUID Version 4 and include https://originstamp.com/u/UUID where UUID is your UUID e.g. in a document you want to timestamp. In the preprint URL field you include your UUID and then it is possible to verify the timestamp within the document (or whatever).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.create_timestamp_with_http_info(authorization, timestamp_request, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param TimestampRequest timestamp_request: DTO for the hash submission. Add all relevant information concerning your hash submission. (required)
        :return: DefaultTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'timestamp_request']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_timestamp" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `create_timestamp`")  # noqa: E501
        # verify the required parameter 'timestamp_request' is set
        if ('timestamp_request' not in params or
                params['timestamp_request'] is None):
            raise ValueError("Missing the required parameter `timestamp_request` when calling `create_timestamp`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timestamp_request' in params:
            body_params = params['timestamp_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v3/timestamp/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultTimestampResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_api_key_usage(self, authorization, **kwargs):  # noqa: E501
        """Usage  # noqa: E501

        With this interface you can receive the current api usage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_api_key_usage(authorization, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :return: DefaultUsageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_api_key_usage_with_http_info(authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.get_api_key_usage_with_http_info(authorization, **kwargs)  # noqa: E501
            return data

    def get_api_key_usage_with_http_info(self, authorization, **kwargs):  # noqa: E501
        """Usage  # noqa: E501

        With this interface you can receive the current api usage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_api_key_usage_with_http_info(authorization, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :return: DefaultUsageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_api_key_usage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_api_key_usage`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v3/api_key/usage', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultUsageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_hash_status(self, authorization, hash_string, **kwargs):  # noqa: E501
        """Status  # noqa: E501

        The request returns information of a certain hash read from the URL parameter. The input parameter is a hash in hex representation. Field \"created\" always set to false.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_hash_status(authorization, hash_string, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param str hash_string: The hash in string representation. (required)
        :return: DefaultTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_hash_status_with_http_info(authorization, hash_string, **kwargs)  # noqa: E501
        else:
            (data) = self.get_hash_status_with_http_info(authorization, hash_string, **kwargs)  # noqa: E501
            return data

    def get_hash_status_with_http_info(self, authorization, hash_string, **kwargs):  # noqa: E501
        """Status  # noqa: E501

        The request returns information of a certain hash read from the URL parameter. The input parameter is a hash in hex representation. Field \"created\" always set to false.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_hash_status_with_http_info(authorization, hash_string, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param str hash_string: The hash in string representation. (required)
        :return: DefaultTimestampResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'hash_string']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hash_status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_hash_status`")  # noqa: E501
        # verify the required parameter 'hash_string' is set
        if ('hash_string' not in params or
                params['hash_string'] is None):
            raise ValueError("Missing the required parameter `hash_string` when calling `get_hash_status`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'hash_string' in params:
            path_params['hash_string'] = params['hash_string']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v3/timestamp/{hash_string}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DefaultTimestampResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_proof(self, authorization, proof_request, **kwargs):  # noqa: E501
        """Proof  # noqa: E501

        This request can be used to proof a submission of a hash. This interface is required to request the evidence. With the help of this proof the verification of a timestamp independent from OriginStamp is necessary. A guide for the verification can be found herehttps://github.com/OriginStampTimestamping/originstamp-verification . Usually, the proof should be requested for each transferred hash and kept with the timestamped data so that an independent verification of the timestamp is possible at any time. As input, the used currency, the hash string and the type of proof is required. Then a file with the information for the submission proof will be returned. If the hash was submitted in an API version lower than 3, a XML file containing the essential information of the Merkle Tree will be returned. Otherwise, the seed file will be returned.  The file name can be found in the header of the response. An example could look like this: content-disposition: attachment; filename=\"certificate_6d70a947e19398f1106ad70a60bd34a8305bdcb624b5b7d43782315517e79cad.pdf\" A sample XML file can be found here https://originstamp.org/assets/proof/proof_6d70a947e19398f1106ad70a60bd34a8305bdcb624b5b7d43782315517e79cad.xml and a sample PDF can be found here https://originstamp.org/assets/proof/certificate_6d70a947e19398f1106ad70a60bd34a8305bdcb624b5b7d43782315517e79cad.pdf .  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_proof(authorization, proof_request, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param ProofRequest proof_request: Information needed to return the hash status information. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_proof_with_http_info(authorization, proof_request, **kwargs)  # noqa: E501
        else:
            (data) = self.get_proof_with_http_info(authorization, proof_request, **kwargs)  # noqa: E501
            return data

    def get_proof_with_http_info(self, authorization, proof_request, **kwargs):  # noqa: E501
        """Proof  # noqa: E501

        This request can be used to proof a submission of a hash. This interface is required to request the evidence. With the help of this proof the verification of a timestamp independent from OriginStamp is necessary. A guide for the verification can be found herehttps://github.com/OriginStampTimestamping/originstamp-verification . Usually, the proof should be requested for each transferred hash and kept with the timestamped data so that an independent verification of the timestamp is possible at any time. As input, the used currency, the hash string and the type of proof is required. Then a file with the information for the submission proof will be returned. If the hash was submitted in an API version lower than 3, a XML file containing the essential information of the Merkle Tree will be returned. Otherwise, the seed file will be returned.  The file name can be found in the header of the response. An example could look like this: content-disposition: attachment; filename=\"certificate_6d70a947e19398f1106ad70a60bd34a8305bdcb624b5b7d43782315517e79cad.pdf\" A sample XML file can be found here https://originstamp.org/assets/proof/proof_6d70a947e19398f1106ad70a60bd34a8305bdcb624b5b7d43782315517e79cad.xml and a sample PDF can be found here https://originstamp.org/assets/proof/certificate_6d70a947e19398f1106ad70a60bd34a8305bdcb624b5b7d43782315517e79cad.pdf .  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_proof_with_http_info(authorization, proof_request, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param ProofRequest proof_request: Information needed to return the hash status information. (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'proof_request']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_proof" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `get_proof`")  # noqa: E501
        # verify the required parameter 'proof_request' is set
        if ('proof_request' not in params or
                params['proof_request'] is None):
            raise ValueError("Missing the required parameter `proof_request` when calling `get_proof`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'proof_request' in params:
            body_params = params['proof_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v3/timestamp/proof', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def trigger_timestamp_webhook(self, authorization, webhook_request, **kwargs):  # noqa: E501
        """Dev  # noqa: E501

        With this interface you can trigger manual webhook to see how a webhooks looks like. Please use a hash, that was already timestamped before such as https://originstamp.org/s/9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d6c15b0f00a08 . Usually, the webhook is triggered as soon as the tamper-proof time stamp with the selected crypto currency has been created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.trigger_timestamp_webhook(authorization, webhook_request, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param WebhookRequest webhook_request: DTO for webhook request. (required)
        :return: Defaultstring
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.trigger_timestamp_webhook_with_http_info(authorization, webhook_request, **kwargs)  # noqa: E501
        else:
            (data) = self.trigger_timestamp_webhook_with_http_info(authorization, webhook_request, **kwargs)  # noqa: E501
            return data

    def trigger_timestamp_webhook_with_http_info(self, authorization, webhook_request, **kwargs):  # noqa: E501
        """Dev  # noqa: E501

        With this interface you can trigger manual webhook to see how a webhooks looks like. Please use a hash, that was already timestamped before such as https://originstamp.org/s/9f86d081884c7d659a2feaa0c55ad015a3bf4f1b2b0b822cd15d6c15b0f00a08 . Usually, the webhook is triggered as soon as the tamper-proof time stamp with the selected crypto currency has been created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.trigger_timestamp_webhook_with_http_info(authorization, webhook_request, async=True)
        >>> result = thread.get()

        :param async bool
        :param str authorization: A valid API key is essential for authorization to handle the request. (required)
        :param WebhookRequest webhook_request: DTO for webhook request. (required)
        :return: Defaultstring
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'webhook_request']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method trigger_timestamp_webhook" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `trigger_timestamp_webhook`")  # noqa: E501
        # verify the required parameter 'webhook_request' is set
        if ('webhook_request' not in params or
                params['webhook_request'] is None):
            raise ValueError("Missing the required parameter `webhook_request` when calling `trigger_timestamp_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'webhook_request' in params:
            body_params = params['webhook_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v3/webhook/start', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Defaultstring',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    OriginStamp Client

    OpenAPI spec version: 3.0
    OriginStamp Documentation: https://docs.originstamp.com
    Contact: mail@originstamp.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "originstamp-client"
VERSION = "1.0.3"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "numpy >= 1.15.4"]

setup(
    name=NAME,
    version=VERSION,
    description="OriginStamp Client",
    author_email="mail@originstamp.com",
    url="https://originstamp.com",
    keywords=["Swagger", "OriginStamp Client"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Python client for the trusted timestamping service OriginStamp, see https://github.com/OriginStampTimestamping/originstamp-client-python.
    """
)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from originstamp_client.api.scheduler_api import SchedulerApi
from originstamp_client.api.timestamp_api import TimestampApi
